@@ -16,7 +16,7 @@
 # Licence:: CC-BY-SA 2.0 or GPL-3+
 #
 
-VERSION = "5.4.3 (Arkanoid)"
+VERSION = "5.4.4.1 (Arkanoid)"
 
 puts "CeWL #{VERSION} Robin Wood (robin@digi.ninja) (https://digi.ninja/)\n"
 
@@ -39,7 +39,7 @@ rescue LoadError => e
 	end
 end
 
-require './cewl_lib'
+require_relative 'cewl_lib'
 
 # Doing this so I can override the allowed? function which normally checks
 # the robots.txt file
@@ -672,10 +672,13 @@ url = ARGV.shift
 # Must have protocol
 url = "http://#{url}" if url !~ /^http(s)?:\/\//
 
+# Taking this back out again. Can't remember why it was put in but have found problems
+# with it in and none with it out so getting rid of it.
+#
 # The spider doesn't work properly if there isn't a / on the end
-if url !~ /\/$/
-	url = "#{url}/"
-end
+#if url !~ /\/$/
+#	url = "#{url}/"
+#end
 
 word_hash = {}
 email_arr = []
@@ -939,9 +942,9 @@ catch :ctrl_c do
 						if wordlist
 							# Remove any symbols
 							if words_with_numbers then
-								words.gsub!(/[^a-z0-9]/i, " ")
+								words.gsub!(/[^[[:alnum:]]]/i, " ")
 							else
-								words.gsub!(/[^a-z]/i, " ")
+								words.gsub!(/[^[[:alpha:]]]/i, " ")
 							end
 
 							# Add to the array
